import typescript from './typescript.mjs';
import handlebars from './handlebars.mjs';
import './html.mjs';
import './javascript.mjs';
import './css.mjs';
import './yaml.mjs';

const lang = Object.freeze({
  "aliases": [
    "gts"
  ],
  "displayName": "Glimmer TS",
  "name": "glimmer-ts",
  "scopeName": "source.gts",
  "injections": {
    "L:source.gts -comment -string": {
      "patterns": [
        {
          "begin": "\\s*(<)(template)\\s*(>)",
          "beginCaptures": {
            "1": {
              "name": "punctuation.definition.tag.html"
            },
            "2": {
              "name": "entity.name.tag.other.html"
            },
            "3": {
              "name": "punctuation.definition.tag.html"
            }
          },
          "end": "(</)(template)(>)",
          "endCaptures": {
            "1": {
              "name": "punctuation.definition.tag.html"
            },
            "2": {
              "name": "entity.name.tag.other.html"
            },
            "3": {
              "name": "punctuation.definition.tag.html"
            }
          },
          "name": "meta.js.embeddedTemplateWithoutArgs",
          "patterns": [
            {
              "include": "text.html.handlebars"
            }
          ]
        },
        {
          "begin": "(<)(template)",
          "beginCaptures": {
            "1": {
              "name": "punctuation.definition.tag.html"
            },
            "2": {
              "name": "entity.name.tag.other.html"
            }
          },
          "end": "(</)(template)(>)",
          "endCaptures": {
            "1": {
              "name": "punctuation.definition.tag.html"
            },
            "2": {
              "name": "entity.name.tag.other.html"
            },
            "3": {
              "name": "punctuation.definition.tag.html"
            }
          },
          "name": "meta.js.embeddedTemplateWithArgs",
          "patterns": [
            {
              "begin": "(?<=\\<template)",
              "end": "(?=\\>)",
              "patterns": [
                {
                  "include": "text.html.handlebars#tag-stuff"
                }
              ]
            },
            {
              "begin": "(>)",
              "beginCaptures": {
                "1": {
                  "name": "punctuation.definition.tag.end.js"
                }
              },
              "contentName": "meta.html.embedded.block",
              "end": "(?=</template>)",
              "patterns": [
                {
                  "include": "text.html.handlebars"
                }
              ]
            }
          ]
        }
      ]
    }
  },
  "patterns": [
    {
      "include": "source.ts"
    }
  ],
  "embeddedLangs": [
    "typescript",
    "handlebars"
  ]
});
var glimmerTs = [
  ...typescript,
  ...handlebars,
  lang
];

export { glimmerTs as default };
